@@ -1,7 +1,7 @@
 package Calendar::Indonesia::Holiday;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-12-09'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -229,6 +229,19 @@ sub _h_pelection {
     ($r);
 }
 
+sub _h_jrelection {
+    my ($r, $opts) = @_;
+    $r->{ind_name}    = "Pilkada Serentak";
+    $r->{eng_name}    = "Joint Regional Election";
+    $r->{is_holiday}  = 1;
+    $r->{tags}        = [qw/political/];
+
+    for (qw(decree_date decree_note)) {
+        $r->{$_} = $opts->{$_} if defined $opts->{$_};
+    }
+    ($r);
+}
+
 sub _jointlv {
     my ($r, $opts) = @_;
     $opts //= {};
@@ -612,6 +625,7 @@ $year_holidays{2015} = [
     _h_eidulf    ({_expand_dm("18-07")}, {hyear=>1436, day=>2}),
     _h_eidula    ({_expand_dm("24-09")}, {hyear=>1436}),
     _h_hijra     ({_expand_dm("14-10")}, {hyear=>1437}),
+    _h_jrelection({_expand_dm("09-12")}, {decree_date => "2015-11-23"}),
 
     _jointlv     ({_expand_dm("16-07")}, {holiday=>$eidulf2015}),
     _jointlv     ({_expand_dm("20-07")}, {holiday=>$eidulf2015}),
@@ -969,7 +983,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.26 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2015-09-03.
+This document describes version 0.27 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2015-12-09.
 
 =head1 SYNOPSIS
 
@@ -1053,6 +1067,8 @@ as working days.
 Contains data from years 2002 to 2016 (joint leave days until
 2016).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1105,6 +1121,8 @@ as working days.
 Contains data from years 2002 to 2016 (joint leave days until
 2016).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1154,6 +1172,8 @@ List holidays and joint leave days ("cuti bersama").
 Contains data from years 2002 to 2016 (joint leave days until
 2016).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1571,6 +1591,8 @@ Return value:  (any)
 
 =head2 list_id_workdays(%args) -> [status, msg, result, meta]
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
